435e92d0ad49164d1b5b156e3fb5ef5ff7b19041
hiram
  Tue Apr 21 12:29:50 2026 -0700
make the ottoRequest table a bit more generic so it can handle both liftOver and assembly requests refs #31811

diff --git src/hg/lib/ottoRequest.sql src/hg/lib/ottoRequest.sql
index f7f1f68916e..aa25761678b 100644
--- src/hg/lib/ottoRequest.sql
+++ src/hg/lib/ottoRequest.sql
@@ -1,20 +1,23 @@
 # ottoRequest.sql was originally generated by the autoSql program, which also 
 # generated ottoRequest.c and ottoRequest.h.  This creates the database representation of
 # an object which can be loaded and saved from RAM in a fairly 
 # automatic way.
 
 #recording requests coming from from functions such as liftRequest
 CREATE TABLE ottoRequest (
     id int unsigned not null auto_increment,	# Auto-incrementing request count
+    requestType varchar(255) not null,	# type of request: liftOver or assembly
     fromDb varchar(255) not null,	# can be a database name or a GC[AF]_ GenArk accession
     toDb varchar(255) not null,	# can be a database name or a GC[AF]_ GenArk accession
     email varchar(255) not null,	# user email address
     comment longtext not null,	# other comments from the input form
     requestTime datetime not null,	# date time request was added
-    doneStatus tinyint unsigned not null,	# # 1 == alignment is complete, 0 == alignment to be done
-    completeTime datetime default null,	# date time for alignment completed and user notified
+    doneStatus tinyint unsigned not null,	# # 1 == process is complete, 0 == process to be done
+    workflowId varchar(255) not null,	# galaxy workflow ID
+    completeTime datetime default null,	# date time for process completed and user notified
               #Indices
     PRIMARY KEY(id),
+    INDEX(requestType),
     INDEX(doneStatus),
     INDEX(requestTime)
 );